@@ -25,8 +25,8 @@ CharacterVector wrap_reverse_pointer(List address_r) {
       output[i] = NA_STRING;
     } else if (address[i].is_ipv6()) {
       auto bytes = address[i].bytes_v6();
-      sprintf(
-        buffer,
+      snprintf(
+        buffer, 40,
         "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
         bytes[0], bytes[1], bytes[2], bytes[3], bytes[4], bytes[5], bytes[6], bytes[7],
         bytes[8], bytes[9], bytes[10], bytes[11], bytes[12], bytes[13], bytes[14], bytes[15]
@@ -39,8 +39,8 @@ CharacterVector wrap_reverse_pointer(List address_r) {
       output[i] = os.str() + "ip.arpa";
     } else {
       auto bytes = address[i].bytes_v4();
-      sprintf(
-        buffer,
+      snprintf(
+        buffer, 40,
         "%i.%i.%i.%i.in-addr.arpa",
         bytes[3], bytes[2], bytes[1], bytes[0]
       );
